@@ -2,7 +2,7 @@ package Clustericious::Client::Object::DateTime;
 
 =head1 NAME
 
-Clustericious::Client::Object::DateTime
+Clustericious::Client::Object::DateTime - Clustericious DateTime object
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ use warnings;
 
 use DateTime::Format::ISO8601;
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 =head1 METHODS
 
